/*
  Listing 2
  Magnetic Gear Clock using
  ATTiny44, running at 8 Mhz works better.
  Using Interrupt and PWM outputs.
  Three coils operated in sequence, wrap around style.
  Coil 1 fades off while coil 2 fades on.
  Coil 2 fades off while coil 3 fades on.
  Coil 3 fades off while coil 1 fades on.
  
  60 Hz pulses are received on ARpin 8 (chip pin 5) = Interrupt 0.
  A count from 1 to 180 is done on these pulses.
  At 60, 120, 180 fading from coil to coil occurs.
  Example provided without warranty.  Use at your own risk.
  */
  
////////////////////////////////////////////////////////////  
  
// Declare variables
int Coil1 = 7;    //Coil 1 connected to ARpin 7 (chip pin 6)
int Coil2 = 6;    //Coil 2 connected to ARpin 6 (chip pin 7)
int Coil3 = 5;    //Coil 3 connected to ARpin 5 (chip pin 8)
volatile boolean C1 = false;  //Trigger for coil 1
volatile boolean C2 = false;  //Trigger for coil 2
volatile boolean C3 = false;  //Trigger for coil 3
volatile int ticks = 0;  //Variable to count input pulses

////////////////////////////////////////////////////////////

void setup()  {
  //Declare coil pins as outputs, Interrupt 0 executes countticks function.
  pinMode(Coil1, OUTPUT);
  pinMode(Coil2, OUTPUT);
  pinMode(Coil3, OUTPUT);
  attachInterrupt(0, countticks, RISING);
}

////////////////////////////////////////////////////////////
//Main Loop
void loop()  {
  if (C1 == true) {
  for(int fadevalue = 255 ;fadevalue >=0; fadevalue -=5) {
    analogWrite(Coil1, fadevalue);
    analogWrite(Coil2, 255 - fadevalue);
    delay(14);
    C1 = false;
  }
  }
  if (C2 == true) {
  for(int fadevalue = 255 ;fadevalue >=0; fadevalue -=5) {
    analogWrite(Coil2, fadevalue);
    analogWrite(Coil3, 255 - fadevalue);
    delay(14);
    C2 = false;
  }
  }
  if (C3 == true) {
  for(int fadevalue = 255 ;fadevalue >=0; fadevalue -=5) {
    analogWrite(Coil3, fadevalue);
    analogWrite(Coil1, 255 - fadevalue);
    delay(14);
    C3 = false;  
  }
  }
}

void countticks()
{
  ticks = ticks + 1;
  if (ticks == 60)  { C1 = true; }
  if (ticks == 120)  { C2 = true; }
  if (ticks == 180)  { C3 = true; ticks = 0; }
}

  
